import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * Resource Type definition for AWS::Rbin::Rule.
 *
 * @cloudformationResource AWS::Rbin::Rule
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html
 */
export declare class CfnRule extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnRule from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnRule;
    /**
     * Rule Arn is unique for each rule.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The unique ID of the retention rule.
     *
     * @cloudformationAttribute Identifier
     */
    readonly attrIdentifier: string;
    /**
     * The lock state for the retention rule.
     *
     * @cloudformationAttribute LockState
     */
    readonly attrLockState: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * The description of the retention rule.
     */
    description?: string;
    /**
     * Information about the exclude resource tags used to identify resources that are excluded by the retention rule.
     */
    excludeResourceTags?: Array<cdk.IResolvable | CfnRule.ResourceTagProperty> | cdk.IResolvable;
    lockConfiguration?: cdk.IResolvable | CfnRule.UnlockDelayProperty;
    /**
     * Information about the resource tags used to identify resources that are retained by the retention rule.
     */
    resourceTags?: Array<cdk.IResolvable | CfnRule.ResourceTagProperty> | cdk.IResolvable;
    /**
     * The resource type retained by the retention rule.
     */
    resourceType: string;
    /**
     * The retention period of the rule.
     */
    retentionPeriod: cdk.IResolvable | CfnRule.RetentionPeriodProperty;
    /**
     * The state of the retention rule.
     */
    status?: string;
    /**
     * Information about the tags assigned to the retention rule.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnRuleProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnRule {
    /**
     * The resource tag of the rule.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-resourcetag.html
     */
    interface ResourceTagProperty {
        /**
         * The tag key of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-resourcetag.html#cfn-rbin-rule-resourcetag-resourcetagkey
         */
        readonly resourceTagKey: string;
        /**
         * The tag value of the resource.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-resourcetag.html#cfn-rbin-rule-resourcetag-resourcetagvalue
         */
        readonly resourceTagValue: string;
    }
    /**
     * The retention period of the rule.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-retentionperiod.html
     */
    interface RetentionPeriodProperty {
        /**
         * The retention period unit of the rule.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-retentionperiod.html#cfn-rbin-rule-retentionperiod-retentionperiodunit
         */
        readonly retentionPeriodUnit: string;
        /**
         * The retention period value of the rule.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-retentionperiod.html#cfn-rbin-rule-retentionperiod-retentionperiodvalue
         */
        readonly retentionPeriodValue: number;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-unlockdelay.html
     */
    interface UnlockDelayProperty {
        /**
         * The unit of time in which to measure the unlock delay.
         *
         * Currently, the unlock delay can be measure only in days.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-unlockdelay.html#cfn-rbin-rule-unlockdelay-unlockdelayunit
         */
        readonly unlockDelayUnit?: string;
        /**
         * The unlock delay period, measured in the unit specified for UnlockDelayUnit.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rbin-rule-unlockdelay.html#cfn-rbin-rule-unlockdelay-unlockdelayvalue
         */
        readonly unlockDelayValue?: number;
    }
}
/**
 * Properties for defining a `CfnRule`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html
 */
export interface CfnRuleProps {
    /**
     * The description of the retention rule.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-description
     */
    readonly description?: string;
    /**
     * Information about the exclude resource tags used to identify resources that are excluded by the retention rule.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-excluderesourcetags
     */
    readonly excludeResourceTags?: Array<cdk.IResolvable | CfnRule.ResourceTagProperty> | cdk.IResolvable;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-lockconfiguration
     */
    readonly lockConfiguration?: cdk.IResolvable | CfnRule.UnlockDelayProperty;
    /**
     * Information about the resource tags used to identify resources that are retained by the retention rule.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-resourcetags
     */
    readonly resourceTags?: Array<cdk.IResolvable | CfnRule.ResourceTagProperty> | cdk.IResolvable;
    /**
     * The resource type retained by the retention rule.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-resourcetype
     */
    readonly resourceType: string;
    /**
     * The retention period of the rule.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-retentionperiod
     */
    readonly retentionPeriod: cdk.IResolvable | CfnRule.RetentionPeriodProperty;
    /**
     * The state of the retention rule.
     *
     * Only retention rules that are in the available state retain resources.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-status
     */
    readonly status?: string;
    /**
     * Information about the tags assigned to the retention rule.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rbin-rule.html#cfn-rbin-rule-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
